==> 0.0.6-prerelease.tar.gz: lib/src/core/widgets/pickers/ModernFormTextPicker.dart <==
part of modern_form_core;

class ModernFormTextPicker<T> extends StatelessWidget {
  final void Function(T) onChanged;
  final String label;
  final String helperText;
  final String value;
  final List<String> suggestions;
  final List<ModernFormBottomSheetModel<T>> list;
  final bool forceMenu;
  final bool enabled;
  final bool sufixIconEnabled;
  final void Function(String) onClear;
  final String Function(dynamic) validator;
  final InputDecoration Function(InputDecoration) decoration;
  final TextStyle Function(TextStyle) textStyle;
  final TextStyle Function(TextStyle) labelStyle;
  final TextStyle Function(TextStyle) errorStyle;
  final Icon prefixIcon;

  const ModernFormTextPicker({
    Key key,
    this.onChanged,
    this.label,
    this.value,
    this.suggestions,
    this.list,
    this.forceMenu = true,
    this.enabled,
    this.sufixIconEnabled,
    this.onClear,
    this.validator,
    this.decoration,
    this.textStyle,
    this.labelStyle,
    this.errorStyle,
    this.prefixIcon,
    this.helperText,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ModernFormFakeTextField(
      prefixIcon: prefixIcon,
      validator: validator,
      label: label ?? "",
      helperText: helperText,
      initialValue: value ?? "",
      sufixIconEnabled: sufixIconEnabled ?? false,
      enabled: enabled ?? true,
      onChanged: onClear,
      decoration: decoration,
      textStyle: textStyle,
      labelStyle: labelStyle,
      errorStyle: errorStyle,
      onTap: () async {
        List<ModernFormBottomSheetModel<String>> _list =
            <ModernFormBottomSheetModel<String>>[];

        if (list == null && suggestions != null) {
          suggestions.forEach((element) {
            _list.add(ModernFormBottomSheetModel<String>(
              text: element,
              value: element,
            ));
          });
        }

        T response = await showModernFormFilterPopupMenu<T>(
          context,
          list: list ?? _list,
          title: label ?? "Selecione",
          forceMenu: forceMenu ?? true,
        );

        if (response != null && onChanged != null) {
          onChanged(response);
        }
      },
    );
  }
}

==> 0.1.2-prerelease.tar.gz: lib/src/core/widgets/pickers/ModernFormTextPicker.dart <==
part of modern_form_core;

class ModernFormTextPicker<T> extends StatelessWidget {
  final void Function(T) onChanged;
  final String label;
  final String helperText;
  final String value;
  final List<String> suggestions;
  final List<ModernFormBottomSheetModel<T>> list;
  final bool forceMenu;
  final bool enabled;
  final bool sufixIconEnabled;
  final void Function(String) onClear;
  final String Function(dynamic) validator;
  final InputDecoration Function(InputDecoration) decoration;
  final TextStyle Function(TextStyle) textStyle;
  final TextStyle Function(TextStyle) labelStyle;
  final TextStyle Function(TextStyle) errorStyle;
  final Icon prefixIcon;

  const ModernFormTextPicker({
    Key key,
    this.onChanged,
    this.label,
    this.value,
    this.suggestions,
    this.list,
    this.forceMenu ,
    this.enabled,
    this.sufixIconEnabled,
    this.onClear,
    this.validator,
    this.decoration,
    this.textStyle,
    this.labelStyle,
    this.errorStyle,
    this.prefixIcon,
    this.helperText,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ModernFormFakeTextField(
      prefixIcon: prefixIcon,
      validator: validator,
      label: label ?? "",
      helperText: helperText,
      initialValue: value ?? "",
      sufixIconEnabled: sufixIconEnabled ?? false,
      enabled: enabled ?? true,
      onChanged: onClear,
      decoration: decoration,
      textStyle: textStyle,
      labelStyle: labelStyle,
      errorStyle: errorStyle,
      onTap: () async {
        List<ModernFormBottomSheetModel<String>> _list =
            <ModernFormBottomSheetModel<String>>[];

        if (list == null && suggestions != null) {
          suggestions.forEach((element) {
            _list.add(ModernFormBottomSheetModel<String>(
              text: element,
              value: element,
            ));
          });
        }

        T response = await showModernFormFilterPopupMenu<T>(
          context,
          list: list ?? _list,
          title: label ?? "Selecione",
          forceMenu: forceMenu,
        );

        if (response != null && onChanged != null) {
          onChanged(response);
        }
      },
    );
  }
}
